"use strict";

var _questions = require("../app/questions");

var q = _interopRequireWildcard(_questions);

var _yeomanGenerator = require("yeoman-generator");

var _yeomanGenerator2 = _interopRequireDefault(_yeomanGenerator);

var _makeScriptName = require("../app/makeScriptName");

var _makeScriptName2 = _interopRequireDefault(_makeScriptName);

var _Interviewer = require("../app/Interviewer");

var _Interviewer2 = _interopRequireDefault(_Interviewer);

var _ignoreFile = require("../app/editor/ignoreFile");

var _npmScript = require("../app/editor/npmScript");

var _package = require("../app/editor/package");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var devDependencies = {
  "webpack": "^1",

  "babel-loader": "^6",
  "file-loader": "^0",

  "express": "^4",
  "webpack-dev-middleware": "^1",
  "webpack-hot-middleware": "^2"
};

var NAME = "Webpack";

module.exports = _yeomanGenerator2.default.Base.extend({
  constructor: function constructor() {
    _yeomanGenerator2.default.Base.apply(this, arguments);
  },
  prompting: function prompting() {
    var _this = this;

    var interviewer = new _Interviewer2.default(this.options);

    interviewer.ask("libraryName", q.libraryName(this.destinationRoot()));
    interviewer.ask("sourceDirectory", q.sourceDirectory(NAME));
    interviewer.ask("targetDirectory", q.targetDirectory(NAME));
    interviewer.ask("scriptSuffix", q.scriptSuffix(NAME));

    interviewer.prompt(this).then(function (answers) {
      _this.answers = answers;
    });
  },
  configuring: function configuring() {
    var _scripts;

    var _answers = this.answers;
    var libraryName = _answers.libraryName;
    var sourceDirectory = _answers.sourceDirectory;
    var targetDirectory = _answers.targetDirectory;
    var scriptSuffix = _answers.scriptSuffix;


    this.fs.copyTpl(this.templatePath("webpack.config.babel.js.ejs"), this.destinationPath("webpack.config.babel.js"), {
      sourceDirectory: sourceDirectory,
      targetDirectory: targetDirectory
    });

    this.fs.copyTpl(this.templatePath("server.js.ejs"), this.destinationPath("server.js"));

    this.fs.copyTpl(this.templatePath("index.js.ejs"), this.destinationPath(sourceDirectory, "index.js"));

    this.fs.copyTpl(this.templatePath("index.html.ejs"), this.destinationPath(sourceDirectory, "index.html"), {
      libraryName: libraryName
    });

    _npmScript.addSequentialTask.call(this, "prepublish", "npm run --production " + (0, _makeScriptName2.default)("build", scriptSuffix));

    _package.mergePackage.call(this, {
      scripts: (_scripts = {}, _defineProperty(_scripts, (0, _makeScriptName2.default)("start", scriptSuffix), "babel-node server.js"), _defineProperty(_scripts, (0, _makeScriptName2.default)("build", scriptSuffix), "webpack"), _defineProperty(_scripts, (0, _makeScriptName2.default)("watch:build", scriptSuffix), "webpack --watch"), _scripts),
      devDependencies: devDependencies
    });

    (0, _ignoreFile.addIgnorePatternsToFile)(this.fs, this.destinationPath(".npmignore"), ["webpack.config.babel.js", "server.js"]);

    (0, _ignoreFile.addIgnorePatternsToFile)(this.fs, this.destinationPath(".npmignore"), ["/" + sourceDirectory]);

    (0, _ignoreFile.addIgnorePatternsToFile)(this.fs, this.destinationPath(".gitignore"), ["/" + targetDirectory]);
  },
  install: function install() {
    this.npmInstall();
  }
});